@@ -109,7 +109,8 @@ class StoreLocation(glance.store.location.StoreLocation):
                     "like so: "
                     "swift+http://user:pass@authurl.com/v1/container/obj"
                     )
-            raise exception.BadStoreUri(uri, reason)
+            logger.error(_("Invalid store uri %(uri)s: %(reason)s") % locals())
+            raise exception.BadStoreUri()
 
         pieces = urlparse.urlparse(uri)
         assert pieces.scheme in ('swift', 'swift+http', 'swift+https')
@@ -140,7 +141,8 @@ class StoreLocation(glance.store.location.StoreLocation):
             if len(cred_parts) == 1:
                 reason = (_("Badly formed credentials '%(creds)s' in Swift "
                             "URI") % locals())
-                raise exception.BadStoreUri(uri, reason)
+                logger.error(reason)
+                raise exception.BadStoreUri()
             elif len(cred_parts) == 3:
                 user = ':'.join(cred_parts[0:2])
             else:
@@ -159,8 +161,9 @@ class StoreLocation(glance.store.location.StoreLocation):
                 path_parts.insert(0, netloc)
                 self.authurl = '/'.join(path_parts)
         except IndexError:
-            reason = _("Badly formed Swift URI")
-            raise exception.BadStoreUri(uri, reason)
+            reason = _("Badly formed Swift URI: %s") % uri
+            logger.error(reason)
+            raise exception.BadStoreUri()
 
     @property
     def swift_auth_url(self):
@@ -303,12 +306,14 @@ class Store(glance.store.base.Store):
         """
         snet = self.snet
         auth_version = self.auth_version
+        full_auth_url = (auth_url if not auth_url or auth_url.endswith('/')
+                         else auth_url + '/')
         logger.debug(_("Creating Swift connection with "
-                     "(auth_address=%(auth_url)s, user=%(user)s, "
+                     "(auth_address=%(full_auth_url)s, user=%(user)s, "
                      "snet=%(snet)s, auth_version=%(auth_version)s)") %
                      locals())
         return swift_client.Connection(
-            authurl=auth_url, user=user, key=key, snet=snet,
+            authurl=full_auth_url, user=user, key=key, snet=snet,
             auth_version=auth_version)
 
     def _option_get(self, param):
